const BASE_DIR = "c:/local/fnf";

class FNFApplication extends w96.WApplication {
    constructor() {
        super();
        this.blobURLs = [];
    }

    /**
     * Converts file system path to blob URL.
     * @param {String} p The path to convert.
     */
    async fsToBlob(p) {
        if(!w96.FS.exists(p))
            return;
        
        const previousBlob = this.blobURLs.find(x=>x.path == p);

        if(previousBlob)
            return previousBlob.url;

        let o = {
            path: p,
            url: URL.createObjectURL(await w96.FS.toBlob(p))
        };

        this.blobURLs.push(o);

        return o.url;
    }

    /**
     * Performs the UI setup.
     */
    async setupUI() {
        const wnd = this.createWindow({
            bodyClass: "fnf-app",
            windowClass: "fnf-wnd",
            body: `<iframe src="https://packages.windows96.net/str/fnf"></iframe>`,
            title: "Friday Night Funkin'",
            taskbar: true,
            initialHeight: 480,
            initialWidth: 640,
            center: true,
            icon: await this.fsToBlob(BASE_DIR + "/icon.png")
        }, true);

        wnd.show();
    }

    /**
     * Main entry point.
     */
    async main(argv) {
        super.main(argv);
        
        // Load main CSS file
        await w96.sys.loader.loadStyleAsync(await this.fsToBlob(BASE_DIR + "/main.css"));

        // Setup UI
        await this.setupUI();
    }

    /**
     * Ran on app closure.
     */
    ontermination() {
        for(let blob of this.blobURLs) {
            URL.revokeObjectURL(blob.url);
        }
    }
}

registerApp("fnf", [], function(args) {
    return w96.WApplication.execAsync(new FNFApplication(), args);
});